Contributing
============

If you would like to contribute to Gstore, please take a look at the
`current issues <https://github.com/sergeyklay/gstore/issues>`_.
If there is a bug or feature that you want but it isn't listed, make an issue
and work on it.
